datastructuretools.Digraph
==========================

.. inheritance-diagram:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph
   :private-bases:

.. autoclass:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.child_graph

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.cyclic_nodes

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.edges

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.is_cyclic

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.nodes

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.parent_graph

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.root_nodes

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.terminal_nodes

Methods
-------

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.partition

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.reverse

Special Methods
---------------

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__eq__

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__ne__

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__str__

   .. note:: Inherited from `__builtin__.object`
